@@ -1,8 +1,8 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
  * (c)LGPL2+
  *
- * LXDE-Qt - a lightweight, Qt based, desktop toolset
- * http://razor-qt.org
+ * LXQt - a lightweight, Qt based, desktop toolset
+ * https://lxqt.org
  *
  * Copyright: 2014 LXQt team
  * Authors:
@@ -38,12 +38,10 @@ class CalendarPopup :  public QDialog
 public:
     CalendarPopup(QWidget *parent = 0);
     ~CalendarPopup();
+    void setFirstDayOfWeek(Qt::DayOfWeek wday);
 
     void show();
 
-protected:
-    virtual bool event(QEvent* );
-
 private:
     QCalendarWidget *cal;
 };
