@@ -1,8 +1,8 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
  * (c)LGPL2+
  *
- * LXDE-Qt - a lightweight, Qt based, desktop toolset
- * http://razor-qt.org
+ * LXQt - a lightweight, Qt based, desktop toolset
+ * https://lxqt.org
  *
  * Copyright: 2013 Razor team
  * Authors:
@@ -42,8 +42,9 @@
 #define ACT_INFO_UPPER      QString(ACT_INFO).toUpper()
 #define ACT_MENU_UPPER      QString(ACT_MENU).toUpper()
 
-DeviceAction::DeviceAction(LXQtMountPlugin *plugin, QObject *parent):
-    mPlugin(plugin)
+DeviceAction::DeviceAction(LXQtMountPlugin *plugin, QObject *parent)
+    : QObject(parent)
+    , mPlugin(plugin)
 {
 }
 
