@@ -1,8 +1,8 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
  * (c)LGPL2+
  *
- * LXDE-Qt - a lightweight, Qt based, desktop toolset
- * http://razor-qt.org
+ * LXQt - a lightweight, Qt based, desktop toolset
+ * https://lxqt.org
  *
  * Copyright: 2010-2011 Razor team
  * Authors:
@@ -74,7 +74,7 @@ void LXQtMountPlugin::settingsChanged()
     if (mDeviceAction == nullptr || mDeviceAction->Type() != actionId)
     {
         delete mDeviceAction;
-        mDeviceAction = DeviceAction::create(actionId, this);
+        mDeviceAction = DeviceAction::create(actionId, this, this);
 
         connect(mPopup, &Popup::deviceAdded, mDeviceAction, &DeviceAction::onDeviceAdded);
         connect(mPopup, &Popup::deviceRemoved, mDeviceAction, &DeviceAction::onDeviceRemoved);
