@@ -1,8 +1,8 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
  * (c)LGPL2+
  *
- * LXDE-Qt - a lightweight, Qt based, desktop toolset
- * http://razor-qt.org
+ * LXQt - a lightweight, Qt based, desktop toolset
+ * https://lxqt.org
  *
  * Copyright: 2012 Razor team
  * Authors:
@@ -286,7 +286,7 @@ void LXQtVolume::showNotification(bool forceShow) const
             if (m_defaultSink->mute())
                 m_notification->setSummary(tr("Volume: muted"));
             else
-                m_notification->setSummary(tr("Volume: %1").arg(QString::number(m_defaultSink->volume())));
+                m_notification->setSummary(tr("Volume: %1%").arg(QString::number(m_defaultSink->volume())));
             m_notification->update();
         }
     }
